@@ -12,7 +12,7 @@ if [ ! -e "${CHANGELOG}" ]; then
   exit 1
 fi
 
-if which iconv >/dev/null; then
+if command -v iconv >/dev/null; then
  iso2utf() {
   iconv -f "ISO-8859-15" -t "UTF-8"
  }
